if [ $# -eq 0 ]
    then
        echo "Missing arguments. Format is 'prepare-for-publish.sh <new-version>'";
        exit 1;
fi

newVersion=$1

filesWithVersion=(
    'plugin.json'
    'resource/frontend/src/assets/docs/Advisor User Guide.md'
    'resource/frontend/src/extension/manifest.json'
    'webapps/advisor/webapp.json'
);

currentPath=`readlink -f "${BASH_SOURCE:-$0}"`;
currentDir=`dirname $currentPath`;
FRONTEND_PATH=$currentDir/../resource/frontend

echo "# Preparing plugin publish to $newVersion... "
echo -n "## Bumping version to ${newVersion} in ${#filesWithVersion[@]} files..."
for ((i = 0; i < ${#filesWithVersion[@]}; i++)); do
    perl -i -pe"s/([0-9]+\.[0-9]+\.[0-9])(?=\"|\.zip|'|$)/${newVersion}/g" "$currentDir/../${filesWithVersion[$i]}"
done
echo "-> Done."
echo -n "## Creating new CHANGELOG entry..."
CHANGELOG_PATH="$currentDir/../CHANGELOG.md";
existingEntry=$(grep -Ei "$newVersion" $CHANGELOG_PATH)
if [ -z "$existingEntry" ]; then
    currentDate=$(date +'%Y-%m');
    newEntry="\n## Version ${newVersion} - $currentDate\n### Customer facing features\n- \n### Internal features\n- \n"
    echo -e "$newEntry" >> $CHANGELOG_PATH;
else
    echo "Changelog entry for $newVersion already exists.";
fi
echo "-> Done."
echo -n "## Compresssing all images..."
pngquant --quality=0-10 $FRONTEND_PATH/src/assets/docs/**/*.png --ext .png -f --skip-if-larger
echo "-> Done."

