#! /bin/sh -
REMOTE=0

while test $# -gt 0
do
    case "$1" in
        -v | --version) 
            VERSION=$2
            shift 2
            ;;
        --remote)
            REMOTE=1
            shift 1
            ;;
        --*)
            echo "Unexpected option: $1"
            exit 1
            ;;
        *) echo "argument $1"
            ;;
    esac
    shift 2
done

SCRIPT_PATH="$(dirname "${BASH_SOURCE[0]}")"
FRONTEND_PATH=$SCRIPT_PATH/../resource/frontend
TEMP_FOLDER_NAME="web-extension-advisor-$VERSION"

S3_BUCKET="advisor-cdn"

echo "# Publishing extension $VERSION... "
echo -n "## Verification of version number... "
if [ -z "$VERSION" ]; then
    echo "✗✗✗ No version number provided ✗✗✗"
    exit 1
elif [[ ! $VERSION =~ ^[0-9]+\.[0-9]+(\.[0-9]+)*$ ]]; then
    echo "✗✗✗ Version number is not valid ✗✗✗"
fi
echo "-> Done."
echo -n "## Building extension... "
make -C $FRONTEND_PATH extension.prod
echo "-> Done."
echo -n "## Creating $TEMP_FOLDER_NAME directory... "
mkdir ./$TEMP_FOLDER_NAME
echo "-> Done."
echo -n "## Compressing extension... "
mkdir -p ./dist
cp -r $FRONTEND_PATH/dist/extension/* ./$TEMP_FOLDER_NAME
zip -r ./$TEMP_FOLDER_NAME/$TEMP_FOLDER_NAME.zip ./$TEMP_FOLDER_NAME/* -q
mv ./$TEMP_FOLDER_NAME/$TEMP_FOLDER_NAME.zip ./dist
echo "-> Done."
if [ "$REMOTE" -eq 1 ]; then
    echo -n "## Verifying aws connection... "
    aws sts get-caller-identity --profile advisor-dev3 > /dev/null
    connection_status="$(echo $?)"
    if [ "$connection_status" -eq 0 ]; then
        echo "-> Done."
    else
        echo "✗✗✗ Connection to AWS failed ✗✗✗"
        exit 1
    fi
    echo -n "## Copying extension to remote... "
    aws s3 cp ./$TEMP_FOLDER_NAME/advisor-$VERSION.zip s3://$S3_BUCKET/advisor-$VERSION.zip --profile advisor-dev3 --acl public-read
    echo "You can download the last version on the following link: https://$S3_BUCKET.s3.eu-west-1.amazonaws.com/advisor-$VERSION.zip"
    echo "-> Done."
fi
echo -n "## Cleaning $TEMP_FOLDER_NAME directory and temp env file... "
rm -rf ./$TEMP_FOLDER_NAME
echo "-> Done."
echo "✓ Extension published !"
