#! /bin/sh -
REMOTE=0

while test $# -gt 0
do
    case "$1" in
        -v | --version) 
            VERSION=$2
            shift 2
            ;;
        --remote)
            REMOTE=1
            shift 1
            ;;
        --*)
            echo "Unexpected option: $1"
            exit 1
            ;;
        *) echo "argument $1"
            ;;
    esac
    shift 2
done

SCRIPT_PATH="$(dirname "${BASH_SOURCE[0]}")"
FRONTEND_PATH=$SCRIPT_PATH/../resource/frontend
PLUGIN_DIST_PATH=$SCRIPT_PATH/../dist
S3_BUCKET="advisor-cdn"

echo "# Publishing plugin $VERSION... "
echo -n "## Installing npm packages... "
cd $FRONTEND_PATH && npm install --legacy-peer-deps && cd -
echo "-> Done."
echo -n "## Building app... "
make -C $FRONTEND_PATH web.prod
make -C $FRONTEND_PATH dss.update
echo "-> Done."
echo -n "## Making plugin... "
make -C $SCRIPT_PATH/.. archive-plugin
echo "-> Done."
if [ "$REMOTE" -eq 1 ]; then
    echo -n "## Verifying aws connection... "
    aws sts get-caller-identity --profile advisor-dev3 > /dev/null
    connection_status="$(echo $?)"
    if [ "$connection_status" -eq 0 ]; then
        echo "-> Done."
    else
        echo "✗✗✗ Connection to AWS failed ✗✗✗"
        exit 1
    fi
    echo -n "## Copying extension to remote... "
    aws s3 cp ./$PLUGIN_DIST_PATH/dss-plugin-advisor-$VERSION.zip s3://$S3_BUCKET/dss-plugin-advisor-$VERSION.zip --profile advisor-dev3 --acl public-read
    echo "-> Done."
fi
echo "✓ Plugin published ! "
