from flask import Blueprint, jsonify, request

from backend.controllers import connection_ctrl
from backend.models.connection import DEFAULT_KEYWORD
from backend.schemas import ConnectionSchema, KeywordSchema
from backend.utils.misc import parse_req

connection = Blueprint("connection", __name__, url_prefix="/connection")


@connection.route("/<connection_id>", methods=["GET"])
def get_by_id(connection_id):
    connection = connection_ctrl.get_by_id_and_set_default_keyword_if_needed(connection_id)
    return jsonify({"connection": ConnectionSchema().dump(connection)})


@connection.route("/<connection_id>", methods=["PUT"])
def update(connection_id):
    req_data = parse_req(
        request=request,
        optional_fields=[
            "dataset_name",
            "keywords_column_name",
            "multiple_matches_mode",
            "secondary_column_name",
            "test_keyword",
        ],
        useless_fields=["id", "view_id"],
    )
    updated_connection = connection_ctrl.update(connection_id=connection_id, **req_data)
    return jsonify({"connection": ConnectionSchema().dump(updated_connection)})


@connection.route("/<connection_id>/populate-keywords-search", methods=["POST"])
def populate_keywords_search(connection_id):
    req_data = parse_req(
        request=request,
        required_fields=[
            "batch_size",
            "batches_offset",
        ],
        optional_fields=["match_string"],
    )
    matching_keywords = connection_ctrl.populate_keywords_search(connection_id=connection_id, **req_data)
    return jsonify({"keywords": KeywordSchema().dump(matching_keywords, many=True)})
