from backend.controllers import user_config_ctrl, auth_ctrl
from flask import Blueprint, jsonify, request

from backend.utils.misc import parse_req

user_config = Blueprint("user_config", __name__, url_prefix="/user-config")


@user_config.route("/toggle-visibility/<card_id>", methods=["PUT"])
def toggle_visibility(card_id: int):
    current_user = auth_ctrl.get_current_dss_user(request)

    new_card_visibility = user_config_ctrl.toggle_card_visibility(
        card_id=int(card_id), dss_user=current_user
    )

    return jsonify(
        {"message": f"Card visibility has been set to {new_card_visibility}"}
    )


@user_config.route("/toggle-unpin/<card_id>", methods=["PUT"])
def toggle_unpin(card_id: int):
    current_user = auth_ctrl.get_current_dss_user(request)

    new_card_unpin = user_config_ctrl.toggle_card_unpin(
        card_id=int(card_id), dss_user=current_user
    )

    return jsonify({"message": f"Card unpin has been set to {new_card_unpin}"})


@user_config.route("/update-cards-ordering", methods=["PUT"])
def update_cards_ordering():
    req_data = parse_req(
        request=request,
        required_fields=["view_id"],
        optional_fields=["cards_ordering"],
    )
    current_user = auth_ctrl.get_current_dss_user(request)

    new_cards_ordering = user_config_ctrl.update_cards_ordering(
        dss_user=current_user, **req_data
    )

    return jsonify({"message": f"Cards ordering is now {new_cards_ordering}"})
