from flask import Flask
from dotenv import load_dotenv, dotenv_values
import os

from multiprocessing import Process

from backend.models import db

from backend.utils.launch_utils import run_migration_upgrade_func, run_create_app
from backend.utils.dataiku_api import dataiku_api

load_dotenv()
dotenv_vals = dotenv_values(".env")

LOCAL_DSS_PROJECT = dotenv_vals["LOCAL_DSS_PROJECT"]

LOCAL_WEBAPP_CONFIG = {
    "connections": {
        "storing_method": "fs",
        "fs_path": dotenv_vals["FS_PATH"],
    }
}

os.environ["DKU_CURRENT_PROJECT_KEY"] = LOCAL_DSS_PROJECT

def test_db(app):
    from backend.controllers import view_ctrl

    with app.app_context():
        view_ctrl.create(name="abc")
        db.session.commit()
        db.session.close()


def get_setup_for_dataiku_client(**kwargs):
    return {
        "plugin_config": {"activate_tracking": False, "connections": {}},
        "webapp_config": kwargs.get("webapp_config", LOCAL_WEBAPP_CONFIG),
        "default_project_key": kwargs.get("default_project_key", LOCAL_DSS_PROJECT),
    }


def setup_dataiku_client(**kwargs):
    dataiku_setup = get_setup_for_dataiku_client(**kwargs)
    dataiku_api.setup(**dataiku_setup)


def run_migration_upgrade():
    p = Process(
        target=run_migration_upgrade_func,
        kwargs={"client_setup": get_setup_for_dataiku_client()},
    )  # We have to do this in another process or webapp somehow won't start
    p.start()
    p.join(timeout=10)


def create_app(**kwargs):
    app = Flask(__name__)

    setup_dataiku_client(**kwargs)
    # run_migration_upgrade()
    run_create_app(app, db)

    return app
